pub struct Function {
pub name: String,
pub func: NativeFunction,
pub arity: Arity,
pub params: String,
pub pure: bool,
}Expand description
A wrapper to hold the NativeFunction and its arity.
Fields
name: Stringfunc: NativeFunctionarity: Arityparams: Stringpure: boolImplementations
Sourceimpl Function
impl Function
Sourcepub fn new(func: NativeFunction, arity: Arity, declaration: &str) -> Self
pub fn new(func: NativeFunction, arity: Arity, declaration: &str) -> Self
Creates a new pure Function from a declaration.
Example: “max(left: Number, right: Number): Number”)
Remarks
If the declaration does not contain an opening brace, the whole string is used as name and the params are left empty.
Sourcepub fn impure(func: NativeFunction, arity: Arity, declaration: &str) -> Self
pub fn impure(func: NativeFunction, arity: Arity, declaration: &str) -> Self
Creates an impure Function.
See also: Function::new