pub fn max(params: &[Value]) -> NativeResultExpand description
Returns the maximum Value of a all supplied parameters.
- Declaration:
max(...): Any
Errors
Will return NativeError::WrongParameterCount if there is a mismatch in the supplied parameters.