cos

Function cos 

pub fn cos(params: &[Value]) -> NativeResult
See the corresponding function descriptions in std::primitive::f64.

Errors

Will return NativeError::WrongParameterCount if there is a mismatch in the supplied parameters. Will return NativeError::WrongParameterType if the the supplied parameters have the wrong type.