int_to_hex

Function int_to_hex 

pub fn int_to_hex(params: &[Value]) -> NativeResult
Converts a Value::Number to an uppercase hex Value::String.

  • Declaration: int_to_hex(value: Number): String

Errors

Will return NativeError::WrongParameterCount if there is a mismatch in the supplied parameters. Will return NativeError::WrongParameterType if the the supplied parameters have the wrong type.