trim

Function trim 

pub fn trim(params: &[Value]) -> NativeResult
Trims the whitespace of a Value::String on both sides.

  • Declaration: trim(text: String): String

Errors

Will return NativeError::WrongParameterCount if there is a mismatch in the supplied parameters. Will return NativeError::WrongParameterType if the the supplied parameters have the wrong type.