trim_left

Function trim_left 

pub fn trim_left(params: &[Value]) -> NativeResult
Trims the whitespace of a Value::String on the left side of the String.

  • Declaration: trim_left(text: String): String

Errors

Will return NativeError::WrongParameterCount if there is a mismatch in the supplied parameters. Will return NativeError::WrongParameterType if the the supplied parameters have the wrong type.