pub fn at(params: &[Value]) -> NativeResultExpand description
Returns the value at the specified index of a Value::String or Value::Array.
- Declaration:
at(values: [String|Array], index: Number): Any
Errors
Will return NativeError::WrongParameterCount if there is a mismatch in the supplied parameters.
Will return NativeError::WrongParameterType if the the supplied parameters have the wrong type.