pub fn cos(params: &[Value]) -> NativeResultExpand description
See the corresponding function descriptions in std::primitive::f64.
Errors
Will return NativeError::WrongParameterCount if there is a mismatch in the supplied parameters.
Will return NativeError::WrongParameterType if the the supplied parameters have the wrong type.