pub fn split(params: &[Value]) -> NativeResultExpand description
Splits a Value::String into a Value::Array according to a separator.
- Declaration:
split(line: String, separator: String): Array<String>
Errors
Will return NativeError::WrongParameterCount if there is a mismatch in the supplied parameters.
Will return NativeError::WrongParameterType if the the supplied parameters have the wrong type.