pub fn millisecond(params: &[Value]) -> NativeResultExpand description
Returns the millisecond portion of a supplied Datetime as a Value::Number.
- Declaration:
millisecond(datetime: Number): Number
Errors
Will return NativeError::WrongParameterCount if there is a mismatch in the supplied parameters.
Will return NativeError::WrongParameterType if the the supplied parameters have the wrong type.