pub type NativeFunction = fn(&[Value]) -> NativeResult;Expand description
A function pointer used to execute native Rust functions.
All parameters to the function are inside a single Vec<Value>.
pub type NativeFunction = fn(&[Value]) -> NativeResult;A function pointer used to execute native Rust functions.
All parameters to the function are inside a single Vec<Value>.